pub struct Has<T: 'static>(/* private fields */);Trait Implementations
Sourceimpl<T: 'static> FetchComponents for Has<T>
impl<T: 'static> FetchComponents for Has<T>
Sourcetype Fetch<'w> = bool
type Fetch<'w> = bool
Per archetype/table state used by this
FetchComponents to fetch Self::ItemSourcetype Item<'w> = bool
type Item<'w> = bool
The item returned by this
FetchComponentsSourcetype State = Arc<Column>
type State = Arc<Column>
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn init_state(world: &mut World, meta: &mut SystemMeta) -> Self::State
fn init_state(world: &mut World, meta: &mut SystemMeta) -> Self::State
initializes ReadWrite for this
FetchComponents type.Sourcefn init_fetch<'w>(
_world: &'w World,
state: &'w Self::State,
index: ArchetypeIndex,
_tick: Tick,
_last_run: Tick,
) -> Self::Fetch<'w>
fn init_fetch<'w>( _world: &'w World, state: &'w Self::State, index: ArchetypeIndex, _tick: Tick, _last_run: Tick, ) -> Self::Fetch<'w>
Creates a new instance of this fetch. Read more
fn init_fetch_opt<'w>( world: &'w World, state: &'w Self::State, index: ArchetypeIndex, tick: Tick, last_run: Tick, ) -> Option<Self::Fetch<'w>>
Sourcefn fetch<'w>(fetch: &Self::Fetch<'w>, _row: Row, _e: Entity) -> Self::Item<'w>
fn fetch<'w>(fetch: &Self::Fetch<'w>, _row: Row, _e: Entity) -> Self::Item<'w>
Fetch
Self::Item for either the given entity in the current [Table],
or for the given entity in the current [Archetype]. This must always be called after
[FetchComponents::set_table] with a table_row in the range of the current [Table] or after
[FetchComponents::set_archetype] with a entity in the current archetype. Read moreAuto Trait Implementations
impl<T> Freeze for Has<T>
impl<T> RefUnwindSafe for Has<T>where
T: RefUnwindSafe,
impl<T> Send for Has<T>where
T: Send,
impl<T> Sync for Has<T>where
T: Sync,
impl<T> Unpin for Has<T>where
T: Unpin,
impl<T> UnwindSafe for Has<T>where
T: UnwindSafe,