pub struct ParamSet<'w, T: 'static + SystemParam>(/* private fields */);Implementations
Sourceimpl<'w, P0: SystemParam + 'static> ParamSet<'w, (P0,)>
impl<'w, P0: SystemParam + 'static> ParamSet<'w, (P0,)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static> ParamSet<'w, (P0, P1)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static> ParamSet<'w, (P0, P1)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static> ParamSet<'w, (P0, P1, P2)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static> ParamSet<'w, (P0, P1, P2)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
pub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
Gets exclusive access to the 3rd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
pub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
Gets exclusive access to the 3rd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
pub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
Gets exclusive access to the 4th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
pub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
Gets exclusive access to the 3rd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
pub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
Gets exclusive access to the 4th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
pub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
Gets exclusive access to the 5th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static, P6: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5, P6)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static, P6: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5, P6)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
pub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
Gets exclusive access to the 3rd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
pub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
Gets exclusive access to the 4th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
pub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
Gets exclusive access to the 5th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p6(&mut self) -> &mut SystemParamItem<'w, P6>
pub fn p6(&mut self) -> &mut SystemParamItem<'w, P6>
Gets exclusive access to the 6th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourceimpl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static, P6: SystemParam + 'static, P7: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5, P6, P7)>
impl<'w, P0: SystemParam + 'static, P1: SystemParam + 'static, P2: SystemParam + 'static, P3: SystemParam + 'static, P4: SystemParam + 'static, P5: SystemParam + 'static, P6: SystemParam + 'static, P7: SystemParam + 'static> ParamSet<'w, (P0, P1, P2, P3, P4, P5, P6, P7)>
Sourcepub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
pub fn p0(&mut self) -> &mut SystemParamItem<'w, P0>
Gets exclusive access to the 0th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
pub fn p1(&mut self) -> &mut SystemParamItem<'w, P1>
Gets exclusive access to the 1st parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
pub fn p2(&mut self) -> &mut SystemParamItem<'w, P2>
Gets exclusive access to the 2nd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
pub fn p3(&mut self) -> &mut SystemParamItem<'w, P3>
Gets exclusive access to the 3rd parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
pub fn p4(&mut self) -> &mut SystemParamItem<'w, P4>
Gets exclusive access to the 4th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
pub fn p5(&mut self) -> &mut SystemParamItem<'w, P5>
Gets exclusive access to the 5th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p6(&mut self) -> &mut SystemParamItem<'w, P6>
pub fn p6(&mut self) -> &mut SystemParamItem<'w, P6>
Gets exclusive access to the 6th parameter in this ParamSet.
No other parameters may be accessed while this one is active.
Sourcepub fn p7(&mut self) -> &mut SystemParamItem<'w, P7>
pub fn p7(&mut self) -> &mut SystemParamItem<'w, P7>
Gets exclusive access to the 7th parameter in this ParamSet.
No other parameters may be accessed while this one is active.